tests Package — DemoPackage 0.0.1 documentation

### Navigation

- index
- modules |
- previous |
- DemoPackage 0.0.1 documentation »
- DemoPackage Package »

# tests Package

## `test_utils` Module

File to test the utility functions.

class `DemoPackage.tests.test_utils.` `TestUtils`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Unittest Class

  `setUp`()

    Unittest setup function and declares a Sequence of 10 numbers.

    Parameters: | self –
    Returns: | None

  `test_print_integer`()

    Testing the print_integer function.

    Parameters: | self –
    Returns: | None

  `test_print_string`()

    Testing the print_string function.

    Parameters: | self –
    Returns: | None

### Navigation

- index
- modules |
- previous |
- DemoPackage 0.0.1 documentation »
- DemoPackage Package »